@@ -1,5 +1,6 @@
 import argparse
 import logging
+import sys
 from typing import Optional, Sequence
 
 import annofabcli.annotation.subcommand_annotation
@@ -11,7 +12,6 @@ import annofabcli.input_data.subcommand_input_data
 import annofabcli.inspection_comment.subcommand_inspection_comment
 import annofabcli.instruction.subcommand_instruction
 import annofabcli.job.subcommand_job
-import annofabcli.labor.subcommand_labor
 import annofabcli.organization_member.subcommand_organization_member
 import annofabcli.project.subcommand_project
 import annofabcli.project_member.subcommand_project_member
@@ -20,6 +20,7 @@ import annofabcli.statistics.subcommand_statistics
 import annofabcli.supplementary.subcommand_supplementary
 import annofabcli.task.subcommand_task
 import annofabcli.task_history.subcommand_task_history
+import annofabcli.task_history_event.subcommand_task_history_event
 
 logger = logging.getLogger(__name__)
 
@@ -43,6 +44,7 @@ def main(arguments: Optional[Sequence[str]] = None):
     if hasattr(args, "subcommand_func"):
         try:
             annofabcli.cli.load_logging_config_from_args(args)
+            logger.info(f"sys.argv='{sys.argv}'")
             args.subcommand_func(args)
         except Exception as e:
             logger.exception(e)
@@ -68,7 +70,6 @@ def create_parser() -> argparse.ArgumentParser:
     annofabcli.inspection_comment.subcommand_inspection_comment.add_parser(subparsers)
     annofabcli.instruction.subcommand_instruction.add_parser(subparsers)
     annofabcli.job.subcommand_job.add_parser(subparsers)
-    annofabcli.labor.subcommand_labor.add_parser(subparsers)
     annofabcli.organization_member.subcommand_organization_member.add_parser(subparsers)
     annofabcli.project.subcommand_project.add_parser(subparsers)
     annofabcli.project_member.subcommand_project_member.add_parser(subparsers)
@@ -77,6 +78,7 @@ def create_parser() -> argparse.ArgumentParser:
     annofabcli.supplementary.subcommand_supplementary.add_parser(subparsers)
     annofabcli.task.subcommand_task.add_parser(subparsers)
     annofabcli.task_history.subcommand_task_history.add_parser(subparsers)
+    annofabcli.task_history_event.subcommand_task_history_event.add_parser(subparsers)
 
     annofabcli.filesystem.subcommand_filesystem.add_parser(subparsers)
     annofabcli.experimental.subcommand_experimental.add_parser(subparsers)
