@@ -7,7 +7,12 @@ from annofabapi.models import Project, ProjectJobInfo, ProjectJobType
 
 import annofabcli
 from annofabcli import AnnofabApiFacade
-from annofabcli.common.cli import AbstractCommandLineInterface, ArgumentParser, build_annofabapi_resource_and_login
+from annofabcli.common.cli import (
+    COMMAND_LINE_ERROR_STATUS_CODE,
+    AbstractCommandLineInterface,
+    ArgumentParser,
+    build_annofabapi_resource_and_login,
+)
 from annofabcli.common.enums import FormatArgument
 
 logger = logging.getLogger(__name__)
@@ -56,17 +61,12 @@ class ListLastJob(AbstractCommandLineInterface):
 
         return project_info
 
-    @annofabcli.utils.allow_404_error
-    def get_project(self, project_id: str) -> Project:
-        project, _ = self.service.api.get_project(project_id)
-        return project
-
     def get_last_job_list(
         self, project_id_list: List[str], job_type: ProjectJobType, add_details: bool = False
     ) -> List[ProjectJobInfo]:
         job_list = []
         for project_id in project_id_list:
-            project = self.get_project(project_id)
+            project = self.service.wrapper.get_project_or_none(project_id)
 
             if project is None:
                 logger.warning(f"project_id='{project_id}' のプロジェクトは存在しませんでした。")
@@ -122,7 +122,7 @@ class ListLastJob(AbstractCommandLineInterface):
 
         else:
             print("引数に`--project_id` または `--organization` を指定してください。", file=sys.stderr)
-            return
+            sys.exit(COMMAND_LINE_ERROR_STATUS_CODE)
 
         self.print_job_list(project_id_list, job_type=job_type, add_details=args.add_details)
 
