@@ -5,13 +5,9 @@ import annofabcli
 import annofabcli.common.cli
 import annofabcli.stat_visualization.merge_visualization_dir
 import annofabcli.statistics.list_annotation_count
-import annofabcli.statistics.list_by_date_user
-import annofabcli.statistics.list_cumulative_labor_time
-import annofabcli.statistics.list_labor_time_per_user
-import annofabcli.statistics.list_task_progress
 import annofabcli.statistics.list_worktime
 import annofabcli.statistics.summarize_task_count
-import annofabcli.statistics.summarize_task_count_by_task_id
+import annofabcli.statistics.summarize_task_count_by_task_id_group
 import annofabcli.statistics.summarize_task_count_by_user
 import annofabcli.statistics.visualize_annotation_count
 import annofabcli.statistics.visualize_statistics
@@ -23,13 +19,9 @@ def parse_args(parser: argparse.ArgumentParser):
 
     # サブコマンドの定義
     annofabcli.statistics.list_annotation_count.add_parser(subparsers)
-    annofabcli.statistics.list_by_date_user.add_parser(subparsers)
-    annofabcli.statistics.list_cumulative_labor_time.add_parser(subparsers)
-    annofabcli.statistics.list_labor_time_per_user.add_parser(subparsers)
-    annofabcli.statistics.list_task_progress.add_parser(subparsers)
     annofabcli.statistics.list_worktime.add_parser(subparsers)
     annofabcli.statistics.summarize_task_count.add_parser(subparsers)
-    annofabcli.statistics.summarize_task_count_by_task_id.add_parser(subparsers)
+    annofabcli.statistics.summarize_task_count_by_task_id_group.add_parser(subparsers)
     annofabcli.statistics.summarize_task_count_by_user.add_parser(subparsers)
     annofabcli.statistics.visualize_statistics.add_parser(subparsers)
     annofabcli.statistics.visualize_annotation_count.add_parser(subparsers)
