@@ -2,81 +2,106 @@ import argparse
 import logging
 import multiprocessing
 import sys
+from dataclasses import dataclass
 from functools import partial
 from typing import List, Optional, Tuple
 
 import annofabapi
 import requests
 from annofabapi.dataclass.task import Task
-from annofabapi.models import ProjectMemberRole
+from annofabapi.models import ProjectMemberRole, TaskStatus
 
 import annofabcli
 import annofabcli.common.cli
 from annofabcli import AnnofabApiFacade
 from annofabcli.common.cli import (
-    AbstracCommandCinfirmInterface,
+    COMMAND_LINE_ERROR_STATUS_CODE,
     AbstractCommandLineInterface,
+    AbstractCommandLineWithConfirmInterface,
     ArgumentParser,
     build_annofabapi_resource_and_login,
 )
 from annofabcli.common.facade import TaskQuery, match_task_with_query
+from annofabcli.common.utils import add_dryrun_prefix
 
 logger = logging.getLogger(__name__)
 
 
-class CancelAcceptanceMain(AbstracCommandCinfirmInterface):
+@dataclass(frozen=True)
+class User:
+    account_id: str
+    user_id: str
+    username: str
+
+
+class CancelAcceptanceMain(AbstractCommandLineWithConfirmInterface):
     def __init__(self, service: annofabapi.Resource, all_yes: bool = False):
         self.service = service
         self.facade = AnnofabApiFacade(service)
-        AbstracCommandCinfirmInterface.__init__(self, all_yes)
+        AbstractCommandLineWithConfirmInterface.__init__(self, all_yes)
 
     def cancel_acceptance_for_task(
         self,
         project_id: str,
         task_id: str,
-        acceptor_user_id: Optional[str] = None,
+        acceptor: Optional[User] = None,
         assign_last_acceptor: bool = True,
         task_query: Optional[TaskQuery] = None,
         task_index: Optional[int] = None,
+        dryrun: bool = False,
     ) -> bool:
+        def get_user_id(user: Optional[User]) -> Optional[str]:
+            return user.user_id if user is not None else None
+
         logging_prefix = f"{task_index + 1} 件目" if task_index is not None else ""
 
         try:
             task, _ = self.service.api.get_task(project_id, task_id)
 
-            if task["status"] != "complete":
+            if task["status"] != TaskStatus.COMPLETE.value:
                 logger.warning(
                     f"{logging_prefix}: task_id = {task_id} は受入完了でありません。"
                     f"status = {task['status']}, phase={task['phase']}"
                 )
                 return False
 
-            acceptor_account_id = None
+            actual_acceptor: Optional[User] = None
             if assign_last_acceptor:
                 acceptor_account_id = task["account_id"]
                 if acceptor_account_id is not None:
-                    user_info = self.facade.get_project_member_from_account_id(project_id, acceptor_account_id)
-                    if user_info is not None:
-                        acceptor_user_id = user_info["user_id"]
+                    member = self.facade.get_project_member_from_account_id(project_id, acceptor_account_id)
+                    if member is not None:
+                        actual_acceptor = User(
+                            account_id=member["account_id"], user_id=member["user_id"], username=member["username"]
+                        )
+                    else:
+                        logger.warning(f"account_id='{acceptor_account_id}' であるユーザは見つかりませんでした。")
+                        return False
+            else:
+                actual_acceptor = acceptor
 
             if not match_task_with_query(Task.from_dict(task), task_query):
                 logger.debug(f"{logging_prefix} : task_id = {task_id} : TaskQueryの条件にマッチしないため、スキップします。")
                 return False
 
             if not self.confirm_processing(
-                f"{logging_prefix}: task_id = {task_id} のタスクの受入を取り消しますか？ user_id = '{acceptor_user_id}' に割り当てます。"
+                f"{logging_prefix}: task_id = {task_id} のタスクの受入を取り消しますか？ "
+                f"user_id = '{get_user_id(actual_acceptor)}' のユーザに割り当てます。"
             ):
                 return False
 
+            logger.debug(
+                f"{logging_prefix}: task_id = {task_id} のタスクの受入を取り消し、"
+                f"user_id = '{get_user_id(actual_acceptor)}' のユーザに割り当てます。"
+            )
             request_body = {
                 "status": "not_started",
-                "account_id": acceptor_account_id,
+                "account_id": actual_acceptor.account_id if actual_acceptor is not None else None,
                 "last_updated_datetime": task["updated_datetime"],
             }
-            self.service.api.operate_task(project_id, task_id, request_body=request_body)
-            logger.info(
-                f"{logging_prefix} : task_id = {task_id} の受け入れ取り消しが成功しました。 user_id = '{acceptor_user_id}' に割り当てます。"
-            )
+            if not dryrun:
+                self.service.api.operate_task(project_id, task_id, request_body=request_body)
+            logger.info(f"{logging_prefix} : task_id = {task_id} の受け入れ取り消しが成功しました。")
             return True
 
         except requests.exceptions.HTTPError as e:
@@ -88,18 +113,20 @@ class CancelAcceptanceMain(AbstracCommandCinfirmInterface):
         self,
         tpl: Tuple[int, str],
         project_id: str,
-        acceptor_user_id: Optional[str] = None,
+        acceptor: Optional[User] = None,
         assign_last_acceptor: bool = True,
         task_query: Optional[TaskQuery] = None,
+        dryrun: bool = False,
     ) -> bool:
         task_index, task_id = tpl
         return self.cancel_acceptance_for_task(
             project_id=project_id,
             task_id=task_id,
-            acceptor_user_id=acceptor_user_id,
+            acceptor=acceptor,
             assign_last_acceptor=assign_last_acceptor,
             task_query=task_query,
             task_index=task_index,
+            dryrun=dryrun,
         )
 
     def cancel_acceptance_for_task_list(
@@ -110,6 +137,7 @@ class CancelAcceptanceMain(AbstracCommandCinfirmInterface):
         assign_last_acceptor: bool = True,
         task_query: Optional[TaskQuery] = None,
         parallelism: Optional[int] = None,
+        dryrun: bool = False,
     ):
         """
         タスクを受入取り消しする
@@ -125,14 +153,23 @@ class CancelAcceptanceMain(AbstracCommandCinfirmInterface):
         if task_query is not None:
             task_query = self.facade.set_account_id_of_task_query(project_id, task_query)
 
+        acceptor: Optional[User] = None
+        if acceptor_user_id is not None:
+            member = self.facade.get_project_member_from_user_id(project_id, acceptor_user_id)
+            if member is not None:
+                acceptor = User(account_id=member["account_id"], user_id=member["user_id"], username=member["username"])
+            else:
+                raise RuntimeError(f"user_id='{acceptor_user_id}' であるプロジェクトメンバは見つかりませんでした。")
+
         success_count = 0
         if parallelism is not None:
             partial_func = partial(
                 self.cancel_acceptance_for_wrapper,
                 project_id=project_id,
-                acceptor_user_id=acceptor_user_id,
+                acceptor=acceptor,
                 assign_last_acceptor=assign_last_acceptor,
                 task_query=task_query,
+                dryrun=dryrun,
             )
             with multiprocessing.Pool(parallelism) as pool:
                 result_bool_list = pool.map(partial_func, enumerate(task_id_list))
@@ -146,9 +183,10 @@ class CancelAcceptanceMain(AbstracCommandCinfirmInterface):
                     project_id,
                     task_id,
                     task_index=task_index,
-                    acceptor_user_id=acceptor_user_id,
+                    acceptor=acceptor,
                     assign_last_acceptor=assign_last_acceptor,
                     task_query=task_query,
+                    dryrun=dryrun,
                 )
                 if result:
                     success_count += 1
@@ -163,7 +201,7 @@ class CancelAcceptance(AbstractCommandLineInterface):
 
         if args.parallelism is not None and not args.yes:
             print(
-                f"{COMMON_MESSAGE} argument --parallelism: '--parallelism'を指定するときは、必ず'--yes'を指定してください。",
+                f"{COMMON_MESSAGE} argument --parallelism: '--parallelism'を指定するときは、必ず ``--yes`` を指定してください。",
                 file=sys.stderr,
             )
             return False
@@ -173,7 +211,10 @@ class CancelAcceptance(AbstractCommandLineInterface):
     def main(self):
         args = self.args
         if not self.validate(args):
-            return
+            sys.exit(COMMAND_LINE_ERROR_STATUS_CODE)
+
+        if args.dryrun:
+            add_dryrun_prefix(logger)
 
         task_id_list = annofabcli.common.cli.get_list_from_args(args.task_id)
 
@@ -211,7 +252,7 @@ def parse_args(parser: argparse.ArgumentParser):
         type=str,
         required=True,
         nargs="+",
-        help="対象のタスクのtask_idを指定します。`file://`を先頭に付けると、task_idの一覧が記載されたファイルを指定できます。",
+        help="対象のタスクのtask_idを指定します。 ``file://`` を先頭に付けると、task_idの一覧が記載されたファイルを指定できます。",
     )
 
     # 受入取消後のタスクの担当者の割当に関して
@@ -230,13 +271,15 @@ def parse_args(parser: argparse.ArgumentParser):
     argument_parser.add_task_query()
 
     parser.add_argument(
-        "--parallelism", type=int, help="使用するプロセス数（並列度）を指定してください。指定する場合は必ず'--yes'を指定してください。指定しない場合は、逐次的に処理します。"
+        "--parallelism", type=int, help="使用するプロセス数（並列度）を指定してください。指定する場合は必ず ``--yes`` を指定してください。指定しない場合は、逐次的に処理します。"
     )
 
+    parser.add_argument("--dryrun", action="store_true", help="取り消しが行われた時の結果を表示しますが、実際は受け入れを取り消しません。")
+
     parser.set_defaults(subcommand_func=main)
 
 
-def add_parser(subparsers: argparse._SubParsersAction):
+def add_parser(subparsers: Optional[argparse._SubParsersAction] = None):
     subcommand_name = "cancel_acceptance"
     subcommand_help = "受入が完了したタスクに対して、受入を取り消します。"
     description = "受入が完了したタスクに対して、受入を取り消します。"
@@ -244,3 +287,4 @@ def add_parser(subparsers: argparse._SubParsersAction):
 
     parser = annofabcli.common.cli.add_parser(subparsers, subcommand_name, subcommand_help, description, epilog=epilog)
     parse_args(parser)
+    return parser
