@@ -4,7 +4,6 @@ from typing import Dict, List, Optional
 
 import annofabapi
 from annofabapi.models import TaskHistory
-from annofabapi.utils import allow_404_error
 
 import annofabcli
 from annofabcli import AnnofabApiFacade
@@ -34,15 +33,11 @@ class ListTaskHistoryMain:
                 filtered_task_history_dict[task_id] = task_history_list
         return filtered_task_history_dict
 
-    @allow_404_error
-    def get_task_histories(self, project_id: str, task_id: str) -> Optional[List[TaskHistory]]:
-        return self.service.api.get_task_histories(project_id, task_id)[0]
-
     def get_task_history_dict_from_project_id(self, project_id: str, task_id_list: List[str]) -> TaskHistoryDict:
         logger.info(f"{len(task_id_list)} 件のタスクの履歴情報を取得します。")
         task_history_dict: TaskHistoryDict = {}
         for task_index, task_id in enumerate(task_id_list):
-            task_history_list = self.get_task_histories(project_id, task_id)
+            task_history_list = self.service.wrapper.get_task_histories_or_none(project_id, task_id)
             if (task_index + 1) % 100 == 0:
                 logger.info(f"{task_index+1} 件のタスクの履歴情報を取得しました。")
             if task_history_list is not None:
@@ -114,9 +109,7 @@ class ListTaskHistory(AbstractCommandLineInterface):
     def main(self):
         args = self.args
 
-        task_id_list = annofabcli.common.cli.get_list_from_args(args.task_id)
-        if len(task_id_list) == 0:
-            task_id_list = None
+        task_id_list = annofabcli.common.cli.get_list_from_args(args.task_id) if args.task_id is not None else None
 
         self.print_task_history_list(
             args.project_id,
